
#include "defs.h"
#include "textview.h"

void            mainwnd_show_about(GtkWidget *w, gpointer data);
void            mainwnd_create();
void            mainwnd_iconify_restore();
void            mainwnd_open(RESULT *res);
void            mainwnd_search(const gchar *word);
void            mainwnd_reset_font();
void            mainwnd_clear_combo();
GtkWidget*      mainwnd_search_method_combo();

struct _mainwnd
{
    gboolean    custom_font, remember_pos;
    gchar       *font;
    gint        x, y, w, h, search;
    GtkWidget   *wnd, *combo_method, *combo_word, *dictbar;
    GSequence   *results;
} mainwnd;

struct _paned
{
    gint        treew, treeh;
    GtkWidget   *pane, *tree;
    EbTextView	*view;
} paned;

